--author: igor29381
--v3.2.1
--date: 21.06.18

ShowCargoUnits = {};

function ShowCargoUnits.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function ShowCargoUnits:load(savegame)
	self.setUnitFillLevel = Utils.appendedFunction(self.setUnitFillLevel, ShowCargoUnits.updateCargoUnits);
	if hasXMLProperty(self.xmlFile, "vehicle.CargoUnits") then
		self.cargoUnits = {};
	end;
	local c = 0;
	while true do
		local baseString = string.format("vehicle.CargoUnits.cargoUnit(%d)",c);
		local index = getXMLString(self.xmlFile, baseString.."#index");
		local fillTypes = getXMLString(self.xmlFile, baseString.."#fillTypes");
		local defaultCargoUnit = Utils.getNoNil(getXMLBool(self.xmlFile, baseString.."#defaultCargoUnit"), false);
		if index == nil or fillTypes == nil then break; end;
		fillTypes = Utils.splitString(" ", fillTypes);
		local units = {};
		units.index = Utils.indexToObject(self.components, index);
		units.count = getNumOfChildren(units.index);
		if defaultCargoUnit then
			self.defaultCargoUnit = units;
		end;
		for i=1, #fillTypes do
			local fillType = FillUtil.fillTypeNameToInt[fillTypes[i]];
			if fillType then
				self.cargoUnits[fillType] = units;
			end;
		end;
		c = c + 1;
	end;
	if self.defaultCargoUnit then
		for fillType,_ in pairs(self.fillUnits[1].fillTypes) do
			if not self.cargoUnits[fillType] then
				self.cargoUnits[fillType] = self.defaultCargoUnit;
			end;
		end;
	end;
end;

function ShowCargoUnits:delete()
end;

function ShowCargoUnits:readStream(streamId, connection)
end;

function ShowCargoUnits:writeStream(streamId, connection)
end;

function ShowCargoUnits:mouseEvent(posX, posY, isDown, isUp, button)
end;

function ShowCargoUnits:keyEvent(unicode, sym, modifier, isDown)
end;

function ShowCargoUnits:update(dt)
end;

function ShowCargoUnits:updateTick(dt)
end;

function ShowCargoUnits:draw()
end;

function ShowCargoUnits:updateCargoUnits()
	local fillUnit = self.fillUnits[1];
	local fillType = fillUnit.currentFillType;
	if self.cargoUnits then
		if fillType ~= 0 then
			local units = self.cargoUnits[fillType];
			local capacity = self:getCapacity(fillType);
			if units and capacity > 0 then
				local unitsToShow = math.ceil(units.count*(self:getFillLevel(fillType)/capacity));
				for i=1, units.count do
					setVisibility(getChildAt(units.index, i-1), i <= unitsToShow);
				end;
			end;
		else
			for _,units in pairs(self.cargoUnits) do
				for i=1, units.count do
					setVisibility(getChildAt(units.index, i-1), false);
				end;
			end;
		end;
	end;
	if fillUnit.currentFillPlane ~= nil then
        for _, node in ipairs(fillUnit.currentFillPlane.nodes) do
            setVisibility(node.node, false);
        end
        fillUnit.currentFillPlane = nil;
    end
    if fillUnit.fillPlanes ~= nil and fillUnit.defaultFillPlane ~= nil then
        local fillPlane;
        local t = 0;
        if fillType ~= FillUtil.FILLTYPE_UNKNOWN then
            fillPlane = fillUnit.fillPlanes[fillType];
            t = fillUnit.fillLevel/fillUnit.capacity;
        end;
        if fillPlane == nil then
            fillPlane = fillUnit.defaultFillPlane;
        end;
        for _, node in ipairs(fillPlane.nodes) do
            local x,y,z, rx,ry,rz, sx,sy,sz = node.animCurve:get(t);
            setTranslation(node.node, x, y, z);
            setRotation(node.node, rx, ry, rz);
            setScale(node.node, sx, sy, sz);
            setVisibility(node.node, fillUnit.fillLevel > 0 or node.alwaysVisible);
        end;
        fillUnit.currentFillPlane = fillPlane;
    end;
end;
